# Simfection

Simfection is an open-source, stochastic, interactions-based infectious disease model. 

## Installation Instructions

Inside the `simfection/` directory, execute

```python
python3 setup.py install
```

To test, change to any other directory and execute `simfection -h`. If it was install correctly, you should see a list of available flags.
